==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TCPRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPRouteSpecFluent<A extends TCPRouteSpecFluent<A>> extends Fluent<A>{
  public A addToParentRefs(Integer index,ParentReference item);
  public A setToParentRefs(Integer index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(Integer index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public TCPRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public TCPRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public TCPRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(Integer index,ParentReference item);
  public TCPRouteSpecFluent.ParentRefsNested<A> editParentRef(Integer index);
  public TCPRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public TCPRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public TCPRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(Integer index,TCPRouteRule item);
  public A setToRules(Integer index,TCPRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRouteRule... items);
  public A addAllToRules(Collection<TCPRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRouteRule... items);
  public A removeAllFromRules(Collection<TCPRouteRule> items);
  public A removeMatchingFromRules(Predicate<TCPRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TCPRouteRule> getRules();
  public List<TCPRouteRule> buildRules();
  public TCPRouteRule buildRule(Integer index);
  public TCPRouteRule buildFirstRule();
  public TCPRouteRule buildLastRule();
  public TCPRouteRule buildMatchingRule(Predicate<TCPRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<TCPRouteRuleBuilder> predicate);
  public A withRules(List<TCPRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRouteRule... rules);
  public Boolean hasRules();
  public TCPRouteSpecFluent.RulesNested<A> addNewRule();
  public TCPRouteSpecFluent.RulesNested<A> addNewRuleLike(TCPRouteRule item);
  public TCPRouteSpecFluent.RulesNested<A> setNewRuleLike(Integer index,TCPRouteRule item);
  public TCPRouteSpecFluent.RulesNested<A> editRule(Integer index);
  public TCPRouteSpecFluent.RulesNested<A> editFirstRule();
  public TCPRouteSpecFluent.RulesNested<A> editLastRule();
  public TCPRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<TCPRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<TCPRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,TCPRouteRuleFluent<TCPRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/TCPRouteSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReferenceFluent;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPRouteSpecFluent<A extends TCPRouteSpecFluent<A>> extends Fluent<A>{
  public A addToParentRefs(Integer index,ParentReference item);
  public A setToParentRefs(Integer index,ParentReference item);
  public A addToParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A addAllToParentRefs(Collection<ParentReference> items);
  public A removeFromParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... items);
  public A removeAllFromParentRefs(Collection<ParentReference> items);
  public A removeMatchingFromParentRefs(Predicate<ParentReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParentRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParentReference> getParentRefs();
  public List<ParentReference> buildParentRefs();
  public ParentReference buildParentRef(Integer index);
  public ParentReference buildFirstParentRef();
  public ParentReference buildLastParentRef();
  public ParentReference buildMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public Boolean hasMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A withParentRefs(List<ParentReference> parentRefs);
  public A withParentRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ParentReference... parentRefs);
  public Boolean hasParentRefs();
  public TCPRouteSpecFluent.ParentRefsNested<A> addNewParentRef();
  public TCPRouteSpecFluent.ParentRefsNested<A> addNewParentRefLike(ParentReference item);
  public TCPRouteSpecFluent.ParentRefsNested<A> setNewParentRefLike(Integer index,ParentReference item);
  public TCPRouteSpecFluent.ParentRefsNested<A> editParentRef(Integer index);
  public TCPRouteSpecFluent.ParentRefsNested<A> editFirstParentRef();
  public TCPRouteSpecFluent.ParentRefsNested<A> editLastParentRef();
  public TCPRouteSpecFluent.ParentRefsNested<A> editMatchingParentRef(Predicate<ParentReferenceBuilder> predicate);
  public A addToRules(Integer index,TCPRouteRule item);
  public A setToRules(Integer index,TCPRouteRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRouteRule... items);
  public A addAllToRules(Collection<TCPRouteRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRouteRule... items);
  public A removeAllFromRules(Collection<TCPRouteRule> items);
  public A removeMatchingFromRules(Predicate<TCPRouteRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TCPRouteRule> getRules();
  public List<TCPRouteRule> buildRules();
  public TCPRouteRule buildRule(Integer index);
  public TCPRouteRule buildFirstRule();
  public TCPRouteRule buildLastRule();
  public TCPRouteRule buildMatchingRule(Predicate<TCPRouteRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<TCPRouteRuleBuilder> predicate);
  public A withRules(List<TCPRouteRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2.TCPRouteRule... rules);
  public Boolean hasRules();
  public TCPRouteSpecFluent.RulesNested<A> addNewRule();
  public TCPRouteSpecFluent.RulesNested<A> addNewRuleLike(TCPRouteRule item);
  public TCPRouteSpecFluent.RulesNested<A> setNewRuleLike(Integer index,TCPRouteRule item);
  public TCPRouteSpecFluent.RulesNested<A> editRule(Integer index);
  public TCPRouteSpecFluent.RulesNested<A> editFirstRule();
  public TCPRouteSpecFluent.RulesNested<A> editLastRule();
  public TCPRouteSpecFluent.RulesNested<A> editMatchingRule(Predicate<TCPRouteRuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentRefsNested<N> extends Nested<N>,ParentReferenceFluent<TCPRouteSpecFluent.ParentRefsNested<N>>{
    public N and();
    public N endParentRef();
    
  }
  public interface RulesNested<N> extends Nested<N>,TCPRouteRuleFluent<TCPRouteSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}
